.. _Emencia: http://www.emencia.com/
.. _Python Paste: http://pythonpaste.org/
.. _buildout: http://www.buildout.org/
.. _Django: https://www.djangoproject.com/
.. _Epaster: https://github.com/emencia/Epaster

This is the `Epaster`_ template to build `Django`_ projects with `Python Paste`_ and `buildout`_.

`See its documentation on Read the Docs <http://epaster.readthedocs.org/en/latest/django.html>`_.
